@@ -208,7 +208,7 @@ class SourcesGroupAdmin(admin.ModelAdmin):
             'fields': (
                 (
             'name',
-            'external_id',
+            'bitrate',
                 ),
 
             )
