@@ -286,16 +286,18 @@ class RecordJob(models.Model):
         return self.__unicode__()
 
     def __unicode__(self):
-        return "%s [start:%s, duration:%s]" \
-    % (self.sources_group,
+        return "[%s] %s [start:%s, duration:%s]" \
+    % (self.id,
+       self.sources_group,
        self.scheduled_start_date,
        self.scheduled_duration)
 
     def slug(self):
-        return slugify("%s-%s-%s" \
+        return slugify("%s-%s-%s-%s" \
     % (self.sources_group,
        self.scheduled_start_date,
-       self.scheduled_duration))
+       self.scheduled_duration,
+       self.id))
 
 
 
